const config = require('./config');
const normapi = require('normapi');
const request = require('request');
const url = require('url');

var api = new normapi();

const check = object => {
	return new Promise((resolve, reject) => {
		const requestUrl = url.resolve(config.checkIfLoggedInUrl, object.appId);
		request.post(
			{
				headers: {
					'content-type': 'application/json'
				},
				url: requestUrl,
				form: {
					uniquekey: object.loggedUser,
					fingerprint: object.fingerprint,
					lalo: object.location
				}
			},
			(err, res, body) => {
				if (err)
					reject(
						new api.queueObjects.error.connection({
							func: '@graphed-check',
							lCode: '-E1',
							msg: 'Hiba a szerver csatlakozás közben!'
						})
					);
				else {
					try {
						body = JSON.parse(body);
						resolve(
							new api.queueObjects.success.basic({
								func: '@graphed-check',
								lCode: '-S1',
								document: body
							})
						);
					} catch (e) {
						reject(
							new api.queueObjects.error.request({
								func: '@graphed-check',
								lCode: '-E2',
								err: e,
								document: res
							})
						);
					}
				}
			}
		);
	});
};

const refresh = object => {
	return new Promise((resolve, reject) => {
		const requestUrl = config.refreshUrl;
		request.post(
			{
				headers: {
					'content-type': 'application/json'
				},
				url: requestUrl,
				form: {
					uniquekey: object.loggedUser,
					lalo: object.location
				}
			},
			(err, res, body) => {
				if (err)
					reject(
						new api.queueObjects.error.connection({
							func: '@graphed-refresh',
							lCode: '-E1',
							msg: 'Hiba a szerver csatlakozás közben!'
						})
					);
				else {
					try {
						body = JSON.parse(body);
						resolve(
							new api.queueObjects.success.basic({
								func: '@graphed-refresh',
								lCode: '-S1',
								document: body
							})
						);
					} catch (e) {
						reject(
							new api.queueObjects.error.request({
								func: '@graphed-refresh',
								lCode: '-E2',
								err: e,
								document: res
							})
						);
					}
				}
			}
		);
	});
};

api.addFunction({ name: 'check' }, check);
api.addFunction({ name: 'refresh' }, refresh);

module.exports = api;
