const authDebug = require('debug')('graphed:functionAuth');
const config = require('./config');
const normapi = require('normapi');
const request = require('request');
const url = require('url');

var api = new normapi();

const authenticateFunction = object => {
	return new Promise(function(resolve, reject) {
		const requestUrl = url.resolve(config.functionAuth, object.appId);
		request.post(
			{
				headers: {
					'content-type': 'application/x-www-form-urlencoded'
				},
				url: requestUrl,
				form: {
					function: object.function,
					adminclass: object.adminClass
				}
			},
			(err, res, body) => {
				if (err)
					reject(
						new api.queueObjects.error.connection({
							func: '@graphed-authenticateFunction',
							lCode: '-E1',
							msg: 'Hiba a szerver csatlakozás közben!',
							document: object.function
						})
					);
				else {
					try {
						body = JSON.parse(body);
						if (body.access != true)
							reject(
								new api.queueObjects.error.forbidden({
									func: '@graphed-authenticateFunction',
									lCode: '-E2',
									msg: 'Nincs hozzáférése a funkcióhoz!',
									document: object.function
								})
							);
						else
							resolve(
								new api.queueObjects.success.basic({
									func: '@graphed-authenticateFunction',
									lCode: '-S1',
									document: body
								})
							);
					} catch (e) {
						reject(
							new api.queueObjects.error.request({
								func: '@graphed-check',
								lCode: '-E3',
								err: e,
								document: res
							})
						);
					}
				}
			}
		);
	});
};

api.addFunction({ name: 'authenticateFunction' }, authenticateFunction);

module.exports = api;
