const config = require('./config');
const normapi = require('normapi');
const request = require('request');
const uuid = require('uuid-v4');
const url = require('url');

var api = new normapi();

const login = object => {
	return new Promise((resolve, reject) => {
		const requestUrl = url.resolve(config.loginUrl, object.appId);
		request.post(
			{
				headers: {
					'content-type': 'application/x-www-form-urlencoded'
				},
				url: requestUrl,
				form: {
					uniquekey: uuid(),
					email: object.email,
					password: object.password,
					fingerprint: object.fingerprint,
					lalo: object.lalo,
					keepmeloggedin: object.keepmeloggedin
				}
			},
			(err, res, body) => {
				if (err)
					reject(
						new api.queueObjects.error.connection({
							func: '@graphed-login',
							lCode: '-E1',
							msg: 'Hiba a szerver csatlakozás közben!'
						})
					);
				else {
					try {
						body = JSON.parse(body);
						if (body.error)
							reject(
								new api.queueObjects.error.authentication({
									func: '@graphed-login',
									lCode: '-E2',
									msg: 'Sikertelen bejelentkezés!'
								})
							);
						else
							resolve(
								new api.queueObjects.success.basic({
									func: '@graphed-login',
									lCode: '-S1',
									document: body
								})
							);
					} catch (e) {
						reject(
							new api.queueObjects.error.request({
								func: '@graphed-login',
								lCode: '-E3',
								err: e,
								document: res
							})
						);
					}
				}
			}
		);
	});
};

const logout = object => {
	return new Promise((resolve, reject) => {
		const requestUrl = url.resolve(config.logoutUrl, object.appId);
		request.post(
			{
				headers: {
					'content-type': 'application/x-www-form-urlencoded'
				},
				url: requestUrl,
				form: {
					uniquekey: object.loggedUser,
					fingerprint: object.fingerprint,
					lalo: object.location
				}
			},
			(err, res, body) => {
				if (err)
					reject(
						new api.queueObjects.error.connection({
							func: '@graphed-logout',
							lCode: '-E1',
							msg: 'Hiba a szerver csatlakozás közben!'
						})
					);
				else {
					try {
						body = JSON.parse(body);
						if (body.error)
							reject(
								new api.queueObjects.error.authentication({
									func: '@graphed-logout',
									lCode: '-E2',
									msg: 'Sikertelen kijelentkezés!'
								})
							);
						else
							resolve(
								new api.queueObjects.success.basic({
									func: '@graphed-logout',
									lCode: '-S1',
									document: body
								})
							);
					} catch (e) {
						reject(
							new api.queueObjects.error.request({
								func: '@graphed-logout',
								lCode: '-E3',
								err: e,
								document: res
							})
						);
					}
				}
			}
		);
	});
};

api.addFunction({ name: 'login' }, login);
api.addFunction({ name: 'logout' }, logout);

module.exports = api;
